@@ -5,6 +5,7 @@ from datetime import datetime, timezone
 from pathlib import Path
 import os
 import time
+import socket
 
 from datadbs.general import GeneralData
 
@@ -52,6 +53,13 @@ class Rethink_DBS(GeneralData):
                                                     port=self.port)
                 self.logger.info(
                     "Connected to RethinkDB without database selected")
+        except (socket.error,
+                ConnectionResetError,
+                ConnectionAbortedError) as conn_error:
+            msg = f'''PD_TOA_-1 + {conn_error}, ConnectionClosed rc_enu connection....'''
+            self.logger.exception(kwargs["origin_exception"])
+            rc = None
+            raise conn_error
         except Exception as ex:
             self.logger.exception(
                 "Excepcion al conectar a Rethinkdb %s" % ex)
@@ -69,14 +77,14 @@ class Rethink_DBS(GeneralData):
     def set_defaultdb(self, dbname: str, first_time=False):
         if dbname:
             self.default_db = dbname
-            print("Station %s, db %s" %(self.station, self.default_db))
+            print("Station %s, db %s" % (self.station, self.default_db))
             if first_time:
                 self.logger.info("Database set on %s by default" % dbname)
 
     @property
     def defaultdb(self):
         return self.default_db
-            
+
     async def server_info(self):
         self.logger.info("Info from server obtained")
         return await self.session.server()
@@ -87,7 +95,7 @@ class Rethink_DBS(GeneralData):
             await create_db(defaultdb)
         if not dbname:
             result = self.session.use(self.defaultdb)
-            self.set_defaultdb(dbname, first_time=True)            
+            self.set_defaultdb(dbname, first_time=True)
             self.logger.info("Set default db to use on session %s" % dbname)
             return result
         else:
@@ -116,7 +124,7 @@ class Rethink_DBS(GeneralData):
                 result = "Database exists"
         except Exception as e:
             print("An exception happen when try to create a database: %s" % e)
-            self.logger.exception("Error al intentar crear Database %s"%e)
+            self.logger.exception("Error al intentar crear Database %s" % e)
         return result
 
     async def delete_db(self, dbname: str):
@@ -243,13 +251,13 @@ class Rethink_DBS(GeneralData):
         return self.default_db
 
     async def update_data(self, table_name, id, conditional_data):
-        dbname = self.defaultdb        
+        dbname = self.defaultdb
         self.logger.info("Updating data in %s" % table_name)
         if table_name in self.tables[self.default_db]:
             await self.r.db(dbname).table(table_name).get(id).update(conditional_data).run(self.session)
 
     async def replace_data(self, table_name, id, conditional_data):
-        dbname = self.defaultdb        
+        dbname = self.defaultdb
         self.logger.info("Replacing data in %s" % table_name)
         if table_name in self.tables[dbname]:
             await self.r.db(dbname).table(table_name).get(id).replace(conditional_data).run(self.session)
